Package {muiCharts}


Type: Package
Title: 'MUI X Charts' for 'shiny' Apps and 'Quarto'
Version: 0.1.0
Maintainer: Felix Luginbuhl <felix.luginbuhl@protonmail.ch>
Description: 'MUI X Charts' React chart components for data visualization for building 'shiny' applications and 'quarto' documents. Bundles the MIT-licensed community edition of the '@mui/x-charts' JavaScript library (the commercial 'Pro' tier is not included).
License: MIT + file LICENSE
Encoding: UTF-8
Language: en-US
LazyData: true
RoxygenNote: 7.3.3
Depends: R (≥ 3.5)
Imports: muiMaterial (≥ 0.2.1), htmltools, shiny.react (≥ 0.4.0), utils
Suggests: dplyr, tidyr, knitr, rmarkdown, testthat (≥ 3.0.0)
Config/testthat/edition: 3
URL: https://github.com/lgnbhl/muiCharts
BugReports: https://github.com/lgnbhl/muiCharts/issues
NeedsCompilation: no
Packaged: 2026-07-19 10:30:22 UTC; felix
Author: Felix Luginbuhl ORCID iD [aut, cre, cph], MUI [cph] (Copyright holder of the bundled '@mui/x-charts' JavaScript library and its '@mui/x-charts-vendor', '@mui/x-internals', '@mui/x-internal-gestures' and '@mui/system' (subpath imports) helpers; see LICENSE.note), Mike Bostock [cph] (Copyright holder of the bundled D3 modules and 'internmap' (ISC license), vendored via '@mui/x-charts-vendor'; see LICENSE.note), Meta Platforms, Inc. and affiliates [cph] (Copyright holder of the bundled 'react-is', 'prop-types' and 'use-sync-external-store' JavaScript libraries; 'react' and 'react-dom' are declared as peer dependencies and provided at runtime by 'shiny.react')
Repository: CRAN
Date/Publication: 2026-07-28 16:20:02 UTC

AnimatedArea

Description

https://mui.com/x/api/charts/animated-area/

Usage

AnimatedArea(...)

Arguments

...

Props to pass to the component.

Details

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


AnimatedLine

Description

https://mui.com/x/api/charts/animated-line/

Usage

AnimatedLine(...)

Arguments

...

Props to pass to the component.

Details

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


AreaElement

Description

https://mui.com/x/api/charts/area-element/

Usage

AreaElement(...)

Arguments

...

Props to pass to the component.

Details

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


AreaPlot

Description

https://mui.com/x/api/charts/area-plot/

Usage

AreaPlot(...)

Arguments

...

Props to pass to the component.

Details

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


BarChart

Description

https://mui.com/x/api/charts/bar-chart/

Usage

BarChart(...)

Arguments

...

Props to pass to the component.

Details

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


BarElement

Description

https://mui.com/x/api/charts/bar-element/

Usage

BarElement(...)

Arguments

...

Props to pass to the component.

Details

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


BarLabel

Description

https://mui.com/x/api/charts/bar-label/

Usage

BarLabel(...)

Arguments

...

Props to pass to the component.

Details

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


BarPlot

Description

https://mui.com/x/api/charts/bar-plot/

Usage

BarPlot(...)

Arguments

...

Props to pass to the component.

Details

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


ChartsAxis

Description

https://mui.com/x/api/charts/charts-axis/

Usage

ChartsAxis(...)

Arguments

...

Props to pass to the component.

Details

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


ChartsAxisHighlight

Description

https://mui.com/x/api/charts/charts-axis-highlight/

Usage

ChartsAxisHighlight(...)

Arguments

...

Props to pass to the component.

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


ChartsAxisHighlightPath

Description

Low-level composition component of MUI X Charts. See https://mui.com/x/react-charts/composition/.

Usage

ChartsAxisHighlightPath(...)

Arguments

...

Props to pass to the component.

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


ChartsAxisTooltipContent

Description

https://mui.com/x/api/charts/charts-axis-tooltip-content/

Usage

ChartsAxisTooltipContent(...)

Arguments

...

Props to pass to the component.

Details

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


ChartsBrushOverlay

Description

https://mui.com/x/api/charts/charts-brush-overlay/

Usage

ChartsBrushOverlay(...)

Arguments

...

Props to pass to the component.

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


ChartsClipPath

Description

https://mui.com/x/api/charts/charts-clip-path/

Usage

ChartsClipPath(...)

Arguments

...

Props to pass to the component.

Details

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


ChartsContainer

Description

https://mui.com/x/api/charts/charts-container/

Usage

ChartsContainer(...)

Arguments

...

Props to pass to the component.

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


ChartsDataProvider

Description

https://mui.com/x/api/charts/charts-data-provider/

Usage

ChartsDataProvider(...)

Arguments

...

Props to pass to the component.

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


ChartsGrid

Description

https://mui.com/x/api/charts/charts-grid/

Usage

ChartsGrid(...)

Arguments

...

Props to pass to the component.

Details

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


ChartsItemTooltipContent

Description

https://mui.com/x/api/charts/charts-item-tooltip-content/

Usage

ChartsItemTooltipContent(...)

Arguments

...

Props to pass to the component.

Details

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


ChartsLabel

Description

Low-level composition component of MUI X Charts. See https://mui.com/x/react-charts/composition/.

Usage

ChartsLabel(...)

Arguments

...

Props to pass to the component.

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


ChartsLabelMark

Description

Low-level composition component of MUI X Charts. See https://mui.com/x/react-charts/composition/.

Usage

ChartsLabelMark(...)

Arguments

...

Props to pass to the component.

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


ChartsLayerContainer

Description

Low-level composition component of MUI X Charts. See https://mui.com/x/react-charts/composition/.

Usage

ChartsLayerContainer(...)

Arguments

...

Props to pass to the component.

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


ChartsLegend

Description

https://mui.com/x/api/charts/charts-legend/

Usage

ChartsLegend(...)

Arguments

...

Props to pass to the component.

Details

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


ChartsLocalizationProvider

Description

https://mui.com/x/api/charts/charts-localization-provider/

Usage

ChartsLocalizationProvider(...)

Arguments

...

Props to pass to the component.

Details

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


ChartsReferenceLine

Description

https://mui.com/x/api/charts/charts-reference-line/

Usage

ChartsReferenceLine(...)

Arguments

...

Props to pass to the component.

Details

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


ChartsSurface

Description

https://mui.com/x/api/charts/charts-surface/

Usage

ChartsSurface(...)

Arguments

...

Props to pass to the component.

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


ChartsSvgLayer

Description

Low-level composition component of MUI X Charts. See https://mui.com/x/react-charts/composition/.

Usage

ChartsSvgLayer(...)

Arguments

...

Props to pass to the component.

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


ChartsText

Description

https://mui.com/x/api/charts/charts-text/

Usage

ChartsText(...)

Arguments

...

Props to pass to the component.

Details

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


ChartsToolbar

Description

https://mui.com/x/api/charts/toolbar/

Wraps the Toolbar component of @mui/x-charts. It is exported as ChartsToolbar in R because muiMaterial already exports Material UI's Toolbar (the AppBar one) and the two packages are commonly attached together.

Usage

ChartsToolbar(...)

Arguments

...

Props to pass to the component.

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


ChartsToolbarButton

Description

https://mui.com/x/api/charts/toolbar-button/

Wraps the ToolbarButton component of @mui/x-charts (renamed ChartsToolbarButton in R for consistency with ChartsToolbar).

Usage

ChartsToolbarButton(...)

Arguments

...

Props to pass to the component.

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


ChartsTooltip

Description

https://mui.com/x/api/charts/charts-tooltip/

Usage

ChartsTooltip(...)

Arguments

...

Props to pass to the component.

Details

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


ChartsTooltipCell

Description

Low-level composition component of MUI X Charts. See https://mui.com/x/react-charts/composition/.

Usage

ChartsTooltipCell(...)

Arguments

...

Props to pass to the component.

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


ChartsTooltipContainer

Description

https://mui.com/x/api/charts/charts-tooltip-container/

Usage

ChartsTooltipContainer(...)

Arguments

...

Props to pass to the component.

Details

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


ChartsTooltipPaper

Description

Low-level composition component of MUI X Charts. See https://mui.com/x/react-charts/composition/.

Usage

ChartsTooltipPaper(...)

Arguments

...

Props to pass to the component.

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


ChartsTooltipRow

Description

Low-level composition component of MUI X Charts. See https://mui.com/x/react-charts/composition/.

Usage

ChartsTooltipRow(...)

Arguments

...

Props to pass to the component.

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


ChartsTooltipTable

Description

Low-level composition component of MUI X Charts. See https://mui.com/x/react-charts/composition/.

Usage

ChartsTooltipTable(...)

Arguments

...

Props to pass to the component.

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


ChartsWrapper

Description

https://mui.com/x/api/charts/charts-wrapper/

Usage

ChartsWrapper(...)

Arguments

...

Props to pass to the component.

Details

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


ChartsXAxis

Description

https://mui.com/x/api/charts/charts-x-axis/

Usage

ChartsXAxis(...)

Arguments

...

Props to pass to the component.

Details

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


ChartsYAxis

Description

https://mui.com/x/api/charts/charts-y-axis/

Usage

ChartsYAxis(...)

Arguments

...

Props to pass to the component.

Details

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


ContinuousColorLegend

Description

https://mui.com/x/api/charts/continuous-color-legend/

Usage

ContinuousColorLegend(...)

Arguments

...

Props to pass to the component.

Details

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


FocusedBar

Description

Low-level composition component of MUI X Charts. See https://mui.com/x/react-charts/composition/.

Usage

FocusedBar(...)

Arguments

...

Props to pass to the component.

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


FocusedLineMark

Description

Low-level composition component of MUI X Charts. See https://mui.com/x/react-charts/composition/.

Usage

FocusedLineMark(...)

Arguments

...

Props to pass to the component.

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


FocusedPieArc

Description

Low-level composition component of MUI X Charts. See https://mui.com/x/react-charts/composition/.

Usage

FocusedPieArc(...)

Arguments

...

Props to pass to the component.

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


FocusedRadarMark

Description

https://mui.com/x/api/charts/focused-radar-mark/

Usage

FocusedRadarMark(...)

Arguments

...

Props to pass to the component.

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


FocusedScatterMark

Description

Low-level composition component of MUI X Charts. See https://mui.com/x/react-charts/composition/.

Usage

FocusedScatterMark(...)

Arguments

...

Props to pass to the component.

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


Gauge

Description

https://mui.com/x/api/charts/gauge/

Usage

Gauge(...)

Arguments

...

Props to pass to the component.

Details

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


GaugeContainer

Description

https://mui.com/x/api/charts/gauge-container/

Usage

GaugeContainer(...)

Arguments

...

Props to pass to the component.

Details

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


GaugeReferenceArc

Description

Low-level composition component of MUI X Charts. See https://mui.com/x/react-charts/composition/.

Usage

GaugeReferenceArc(...)

Arguments

...

Props to pass to the component.

Details

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


GaugeValueArc

Description

Low-level composition component of MUI X Charts. See https://mui.com/x/react-charts/composition/.

Usage

GaugeValueArc(...)

Arguments

...

Props to pass to the component.

Details

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


GaugeValueText

Description

Low-level composition component of MUI X Charts. See https://mui.com/x/react-charts/composition/.

Usage

GaugeValueText(...)

Arguments

...

Props to pass to the component.

Details

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


LineChart

Description

https://mui.com/x/api/charts/line-chart/

Usage

LineChart(...)

Arguments

...

Props to pass to the component.

Details

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


LineElement

Description

https://mui.com/x/api/charts/line-element/

Usage

LineElement(...)

Arguments

...

Props to pass to the component.

Details

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


LineHighlightElement

Description

https://mui.com/x/api/charts/line-highlight-element/

Usage

LineHighlightElement(...)

Arguments

...

Props to pass to the component.

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


LineHighlightPlot

Description

https://mui.com/x/api/charts/line-highlight-plot/

Usage

LineHighlightPlot(...)

Arguments

...

Props to pass to the component.

Details

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


LinePlot

Description

https://mui.com/x/api/charts/line-plot/

Usage

LinePlot(...)

Arguments

...

Props to pass to the component.

Details

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


MarkElement

Description

https://mui.com/x/api/charts/mark-element/

Usage

MarkElement(...)

Arguments

...

Props to pass to the component.

Details

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


MarkPlot

Description

https://mui.com/x/api/charts/mark-plot/

Usage

MarkPlot(...)

Arguments

...

Props to pass to the component.

Details

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


PieArc

Description

https://mui.com/x/api/charts/pie-arc/

Usage

PieArc(...)

Arguments

...

Props to pass to the component.

Details

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


PieArcLabel

Description

https://mui.com/x/api/charts/pie-arc-label/

Usage

PieArcLabel(...)

Arguments

...

Props to pass to the component.

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


PieArcLabelPlot

Description

https://mui.com/x/api/charts/pie-arc-label-plot/

Usage

PieArcLabelPlot(...)

Arguments

...

Props to pass to the component.

Details

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


PieArcPlot

Description

https://mui.com/x/api/charts/pie-arc-plot/

Usage

PieArcPlot(...)

Arguments

...

Props to pass to the component.

Details

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


PieChart

Description

https://mui.com/x/api/charts/pie-chart/

Usage

PieChart(...)

Arguments

...

Props to pass to the component.

Details

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


PiePlot

Description

https://mui.com/x/api/charts/pie-plot/

Usage

PiePlot(...)

Arguments

...

Props to pass to the component.

Details

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


PiecewiseColorLegend

Description

https://mui.com/x/api/charts/piecewise-color-legend/

Usage

PiecewiseColorLegend(...)

Arguments

...

Props to pass to the component.

Details

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


RadarAxis

Description

https://mui.com/x/api/charts/radar-axis/

Usage

RadarAxis(...)

Arguments

...

Props to pass to the component.

Details

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


RadarAxisHighlight

Description

https://mui.com/x/api/charts/radar-axis-highlight/

Usage

RadarAxisHighlight(...)

Arguments

...

Props to pass to the component.

Details

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


RadarChart

Description

https://mui.com/x/api/charts/radar-chart/

Usage

RadarChart(...)

Arguments

...

Props to pass to the component.

Details

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


RadarDataProvider

Description

Low-level composition component of MUI X Charts. See https://mui.com/x/react-charts/composition/.

Usage

RadarDataProvider(...)

Arguments

...

Props to pass to the component.

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


RadarGrid

Description

https://mui.com/x/api/charts/radar-grid/

Usage

RadarGrid(...)

Arguments

...

Props to pass to the component.

Details

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


RadarMetricLabels

Description

https://mui.com/x/api/charts/radar-metric-labels/

Usage

RadarMetricLabels(...)

Arguments

...

Props to pass to the component.

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


RadarSeriesArea

Description

https://mui.com/x/api/charts/radar-series-area/

Usage

RadarSeriesArea(...)

Arguments

...

Props to pass to the component.

Details

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


RadarSeriesMarks

Description

https://mui.com/x/api/charts/radar-series-marks/

Usage

RadarSeriesMarks(...)

Arguments

...

Props to pass to the component.

Details

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


RadarSeriesPlot

Description

https://mui.com/x/api/charts/radar-series-plot/

Usage

RadarSeriesPlot(...)

Arguments

...

Props to pass to the component.

Details

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


Scatter

Description

https://mui.com/x/api/charts/scatter/

Usage

Scatter(...)

Arguments

...

Props to pass to the component.

Details

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


ScatterChart

Description

https://mui.com/x/api/charts/scatter-chart/

Usage

ScatterChart(...)

Arguments

...

Props to pass to the component.

Details

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


ScatterMarker

Description

Low-level composition component of MUI X Charts. See https://mui.com/x/react-charts/composition/.

Usage

ScatterMarker(...)

Arguments

...

Props to pass to the component.

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


ScatterPlot

Description

https://mui.com/x/api/charts/scatter-plot/

Usage

ScatterPlot(...)

Arguments

...

Props to pass to the component.

Details

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


SparkLineChart

Description

https://mui.com/x/api/charts/spark-line-chart/

Usage

SparkLineChart(...)

Arguments

...

Props to pass to the component.

Details

Value

Object with shiny.tag class suitable for use in the UI of a Shiny app.


Mui Charts UI JS dependency

Description

Mui Charts UI JS dependency

Usage

muiChartsDependency()

Value

A list of HTML dependency objects (htmltools::htmlDependency) that load the bundled MUI X Charts JavaScript and its shared MUI Material runtime. The muiMaterial dependency is listed first so its bundle (which provides react, react-dom, @mui/material, @mui/system and the emotion runtime that the charts consume as externals) loads before the chart script. Attach it to custom HTML when building a chart by hand.

Examples

# Inspect the dependencies attached to every muiCharts element.
muiChartsDependency()


Print muiCharts components

Description

When called interactively, renders the component in the IDE viewer panel. Otherwise, falls back to standard shiny.tag printing (raw HTML text).

Usage

## S3 method for class 'muiCharts'
print(x, browse = interactive(), ...)

Arguments

x

A muiCharts object (also inherits shiny.tag).

browse

Whether to render in viewer. Defaults to TRUE in interactive sessions.

...

Additional arguments passed to print.

Value

Invisibly returns x.

Examples

chart <- BarChart(
  series = list(list(data = c(1, 2, 3))),
  height = 300
)
# browse = FALSE prints the underlying HTML instead of opening the viewer.
print(chart, browse = FALSE)


Objects exported from other packages

Description

These objects are imported from other packages. Follow the links below to see their documentation.

shiny.react

JS, reactOutput, renderReact, setInput, triggerEvent


Star Wars Films

Description

A dataset containing information about the Star Wars films, fetched from the Star Wars API (SWAPI).

Usage

starwars_films

Format

A data frame with 6 rows and 10 variables:

title

character. The title of the film.

episode_id

integer. The episode number of the film.

director

character. The name of the director of the film.

producer

character. The name(s) of the producer(s) of the film.

release_date

Date. The release date of the film in ISO 8601 format.

characters

list of character vectors. A list of character names appearing in the film.

planets

list of character vectors. A list of planet names appearing in the film.

starships

list of character vectors. A list of starship names appearing in the film.

vehicles

list of character vectors. A list of vehicle names appearing in the film.

species

list of character vectors. A list of species names appearing in the film.

https://swapi.info/api/films


Star Wars People

Description

A dataset containing information about people (characters) in the Star Wars universe, fetched from the Star Wars API (SWAPI).

Usage

starwars_people

Format

A data frame with 82 rows and 11 variables:

name

character. The name of the character.

height

integer. The height of the character in centimeters.

mass

double. The mass of the character in kilograms.

hair_color

character. The hair color of the character.

skin_color

character. The skin color of the character.

eye_color

character. The eye color of the character.

birth_year

double. The birth year of the character relative to the Battle of Yavin (BBY). A higher number means earlier in the timeline.

gender

character. The gender of the character.

films

list of character vectors. A list of film titles this character appeared in.

starships

list of character vectors. A list of starship names this character has piloted.

vehicles

list of character vectors. A list of vehicle names this character has piloted.

https://swapi.info/api/people


Star Wars Planets

Description

A dataset containing information about planets in the Star Wars universe, fetched from the Star Wars API (SWAPI).

Usage

starwars_planets

Format

A data frame with 60 rows and 11 variables:

name

character. The name of the planet.

rotation_period

integer. The number of standard hours it takes for the planet to complete a single rotation on its axis.

orbital_period

integer. The number of standard days it takes for the planet to orbit once around the local star.

diameter

integer. The diameter of the planet in kilometers.

climate

character. The climate(s) of the planet.

gravity

character. The gravity of the planet relative to standard gravity.

terrain

character. The terrain type(s) found on the planet.

surface_water

double. The percentage of the planet surface covered by water or other bodies of water.

population

double. The average population of sentient beings inhabiting the planet.

residents

list of character vectors. A list of character names who are residents of the planet.

films

list of character vectors. A list of film titles in which this planet appears.

https://swapi.info/api/planets


Star Wars Species

Description

A dataset containing information about species in the Star Wars universe, fetched from the Star Wars API (SWAPI).

Usage

starwars_species

Format

A data frame with 37 rows and 12 variables:

name

character. The name of the species.

classification

character. The classification of the species (e.g. mammal, reptile).

designation

character. The designation of the species (e.g. sentient, reptilian).

average_height

double. The average height of the species in centimeters.

average_lifespan

double. The average lifespan of the species in years.

skin_colors

character. A comma-separated string of common skin colors for the species.

hair_colors

character. A comma-separated string of common hair colors for the species.

eye_colors

character. A comma-separated string of common eye colors for the species.

language

character. The language commonly spoken by the species.

homeworld

character. The name of the planet this species originates from.

people

list of character vectors. A list of character names that are members of this species.

films

list of character vectors. A list of film titles in which this species appears.

https://swapi.info/api/species


Star Wars Starships

Description

A dataset containing information about starships in the Star Wars universe, fetched from the Star Wars API (SWAPI).

Usage

starwars_starships

Format

A data frame with 36 rows and 15 variables:

name

character. The name of the starship.

model

character. The model or official name of the starship.

manufacturer

character. The manufacturer of the starship.

cost_in_credits

double. The cost of the starship new, in galactic credits.

length

double. The length of the starship in meters.

max_atmosphering_speed

double. The maximum speed of the starship in atmosphere. NA if the starship is incapable of atmospheric flight.

crew

double. The number of personnel needed to run or pilot the starship.

passengers

double. The number of non-essential people this starship can transport.

cargo_capacity

double. The maximum cargo load in kilograms.

consumables

character. The maximum length of time the starship can provide consumables for its entire crew without resupplying.

hyperdrive_rating

double. The class of the starship's hyperdrive.

MGLT

double. The maximum number of Megalights this starship can travel in a standard hour.

starship_class

character. The class of the starship.

pilots

list of character vectors. A list of character names who have piloted this starship.

films

list of character vectors. A list of film titles in which this starship appears.

https://swapi.info/api/starships